#!/bin/sh

. speedtest.conf
TOKEN="foo"

speedcheck_prepare()
{
	local server="$1"
	local url1 url2 output answer port checksum

	url1="http://$server/cgi-bin-speedometer.sh?TOKEN=${TOKEN}&BITRATE=1&LINEID=foo&MTYPE=iperf3"
	url2="http://$server/cgi-bin/cgi-bin-speedometer.sh?TOKEN=${TOKEN}&BITRATE=1&LINEID=foo&MTYPE=iperf3"

	# e.g. OK 12345 sha256sum
	output="$( wget -qO - "$url2" )"	# url1 = openwrt | url2 = debian

	set -f; set +f -- $output
	answer=$1	# e.g. OK
	port=$2		# e.g. 12345
	checksum=$3	# e.g. 64byte-hex-sha256sum

	test "$answer" = 'OK' || {
		logger -s "error: answer != ok - out: '$output'"
		return 64
	}

	test "$port" -ge 1024 -a "$port" -le 65535 || {
		logger -s "error: port not in range - out: '$output'"
		return 128
	}

	test "${#checksum}" -eq 64 || {
		logger -s "error: checksum != sha256 - out: '$output'"
		return 8
	}

	echo "$port"
}

speedcheck()
{
	local ip="${1:-intercity-vpn.de}"
	local port=

	port="$( speedcheck_prepare $ip )" && {
	    export resultDown="$( iperf3 --client "$ip" --port "$port" --json )"
	}
	export midStatus="-1"
	port="$( speedcheck_prepare $ip )" && {
	    export resultUp="$( iperf3 --client "$ip" --port "$port" --reverse --json )"
	}
}

startStatus="-1"
speedcheck "$STSERVER"
endStatus="-1"

timestamp=$(date +%s)

echo "{\"TestData\": {\"ServerID\":\"$STSERVER\", \"Duration\":\"$STDURATION\"" \
"}, \"ResultDownload\": $resultDown, \"ResultUpload\": $resultUp, " \
"\"RouterData\": {\"StartStatus\":\"$startStatus\", \"MidStatus\": \"$midStatus\", " \
"\"EndStatus\":\"$endStatus\"}}" > measurements/$timestamp.json


